@@ -14,6 +14,7 @@ public class ListParameter extends Parameter {
 	private static final long serialVersionUID = 5405965026753332225L;
 	private String type;
 	private String separator;
+	private String defaultValue;
 
 	/**
 	 * 
@@ -25,19 +26,16 @@ public class ListParameter extends Parameter {
 
 	/**
 	 * 
-	 * @param name
-	 *            name
-	 * @param description
-	 *            description
-	 * @param type
-	 *            type
-	 * @param separator
-	 *            separator
+	 * @param name        name
+	 * @param description description
+	 * @param type        type
+	 * @param separator   separator
 	 */
-	public ListParameter(String name, String description, String type, String separator) {
+	public ListParameter(String name, String description, String type, String separator, String defaultValue) {
 		super(name, ParameterType.LIST, description);
 		this.type = type;
 		this.separator = separator;
+		this.defaultValue = defaultValue;
 	}
 
 	/**
@@ -48,8 +46,7 @@ public class ListParameter extends Parameter {
 	}
 
 	/**
-	 * @param type
-	 *            the type to set
+	 * @param type the type to set
 	 */
 	public void setType(String type) {
 		this.type = type;
@@ -66,10 +63,17 @@ public class ListParameter extends Parameter {
 		this.separator = separator;
 	}
 
+	public String getDefaultValue() {
+		return defaultValue;
+	}
+
+	public void setDefaultValue(String defaultValue) {
+		this.defaultValue = defaultValue;
+	}
+
 	@Override
 	public String toString() {
-		return "ListParameter [type=" + type + ", value=" + value + ", separator=" + separator + ", name=" + name
-				+ ", description=" + description + ", typology=" + typology + "]";
+		return "ListParameter [type=" + type + ", separator=" + separator + ", defaultValue=" + defaultValue + "]";
 	}
 
 }
